# setup.py
from setuptools import setup, find_packages

setup(
    name="my_package_shruti",
    version="0.2",
    packages=find_packages(),
    description="A simple hello world package by Shruti",
    author="Shruti",
    author_email="shruti@example.com",
    url="https://github.com/yourusername/my_package_shruti",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
